@@ -51,7 +51,7 @@ static void print_string_stdout(const char *s)
 	Rprintf(s);
 }
 static void (*svm_print_string) (const char *) = &print_string_stdout;
-#if 1
+#if 0
 static void info(const char *fmt,...)
 {
 	char buf[BUFSIZ];
@@ -603,7 +603,6 @@ void Solver::Solve(int l, const QMatrix& Q, const double *p_, const schar *y_,
 			info(".");
 		}
 
-		//int i,j;
 		int i;
     //Rprintf("\n%d ",i);
 		if(select_working_set(i)!=0)
@@ -844,10 +843,7 @@ int Solver::select_working_set(int &out_i)
 	//    -y_j*grad(f)_j < -y_i*grad(f)_i, j in I_low(\alpha)
 	
 	double Gmax = -INF;
-	// double Gmax2 = -INF;
 	int Gmax_idx = -1;
-	// int Gmin_idx = -1;
-	// double obj_diff_min = INF;
 
 	int t;
 	for(t=0;t<active_size;t++)
@@ -3041,38 +3037,14 @@ svm_model *svm_load_model(const char *model_file_name)
 	model->nSV = NULL;
 
 	char cmd[81];
-	int count;
+	int fscanf_output;
 	while(1)
 	{
-		count = fscanf(fp,"%80s",cmd);
-	  if (count <= 0)
-	  {
-  	  REprintf("unknown text in model file: [%s]\n",cmd);
-  	  
-  	  setlocale(LC_ALL, old_locale);
-  	  free(old_locale);
-  	  free(model->rho);
-  	  free(model->label);
-  	  free(model->nSV);
-  	  free(model);
-  	  return NULL;
-  	}
+		fscanf_output = fscanf(fp,"%80s",cmd);
 
 		if(strcmp(cmd,"svm_type")==0)
 		{
-			count = fscanf(fp,"%80s",cmd);
-		  if (count <= 0)
-		  {
-		    REprintf("unknown text in model file: [%s]\n",cmd);
-		    
-		    setlocale(LC_ALL, old_locale);
-		    free(old_locale);
-		    free(model->rho);
-		    free(model->label);
-		    free(model->nSV);
-		    free(model);
-		    return NULL;
-		  }
+			fscanf_output = fscanf(fp,"%80s",cmd);
 			int i;
 			for(i=0;svm_type_table[i];i++)
 			{
@@ -3097,19 +3069,7 @@ svm_model *svm_load_model(const char *model_file_name)
 		}
 		else if(strcmp(cmd,"kernel_type")==0)
 		{		
-			count = fscanf(fp,"%80s",cmd);
-		  if (count <= 0)
-		  {
-		    REprintf("unknown text in model file: [%s]\n",cmd);
-		    
-		    setlocale(LC_ALL, old_locale);
-		    free(old_locale);
-		    free(model->rho);
-		    free(model->label);
-		    free(model->nSV);
-		    free(model);
-		    return NULL;
-		  }
+			fscanf_output = fscanf(fp,"%80s",cmd);
 			int i;
 			for(i=0;kernel_type_table[i];i++)
 			{
@@ -3133,189 +3093,49 @@ svm_model *svm_load_model(const char *model_file_name)
 			}
 		}
 		else if(strcmp(cmd,"degree")==0)
-		{
-			count = fscanf(fp,"%d",&param.degree);
-  		if (count <= 0)
-  		{
-  		  REprintf("unknown text in model file: [%s]\n",cmd);
-  		  
-  		  setlocale(LC_ALL, old_locale);
-  		  free(old_locale);
-  		  free(model->rho);
-  		  free(model->label);
-  		  free(model->nSV);
-  		  free(model);
-  		  return NULL;
-  		}
-		}
+			fscanf_output = fscanf(fp,"%d",&param.degree);
 		else if(strcmp(cmd,"gamma")==0)
-		{
-			count = fscanf(fp,"%lf",&param.gamma);
-  		if (count <= 0)
-  		{
-  		  REprintf("unknown text in model file: [%s]\n",cmd);
-  		  
-  		  setlocale(LC_ALL, old_locale);
-  		  free(old_locale);
-  		  free(model->rho);
-  		  free(model->label);
-  		  free(model->nSV);
-  		  free(model);
-  		  return NULL;
-  		}
-		}
+			fscanf_output = fscanf(fp,"%lf",&param.gamma);
 		else if(strcmp(cmd,"coef0")==0)
-		{
-			count = fscanf(fp,"%lf",&param.coef0);
-		  if (count <= 0)
-		  {
-		    REprintf("unknown text in model file: [%s]\n",cmd);
-		    
-		    setlocale(LC_ALL, old_locale);
-		    free(old_locale);
-		    free(model->rho);
-		    free(model->label);
-		    free(model->nSV);
-		    free(model);
-		    return NULL;
-		  }
-		}
+			fscanf_output = fscanf(fp,"%lf",&param.coef0);
 		else if(strcmp(cmd,"nr_class")==0)
-		{
-			count = fscanf(fp,"%d",&model->nr_class);
-		  if (count <= 0)
-		  {
-		    REprintf("unknown text in model file: [%s]\n",cmd);
-		    
-		    setlocale(LC_ALL, old_locale);
-		    free(old_locale);
-		    free(model->rho);
-		    free(model->label);
-		    free(model->nSV);
-		    free(model);
-		    return NULL;
-		  }
-		}
+			fscanf_output = fscanf(fp,"%d",&model->nr_class);
 		else if(strcmp(cmd,"total_sv")==0)
-		{
-			count = fscanf(fp,"%d",&model->l);
-		  if (count <= 0)
-		  {
-		    REprintf("unknown text in model file: [%s]\n",cmd);
-		    
-		    setlocale(LC_ALL, old_locale);
-		    free(old_locale);
-		    free(model->rho);
-		    free(model->label);
-		    free(model->nSV);
-		    free(model);
-		    return NULL;
-		  }
-		}
+			fscanf_output = fscanf(fp,"%d",&model->l);
 		else if(strcmp(cmd,"rho")==0)
 		{
 			int n = model->nr_class * (model->nr_class-1)/2;
 			model->rho = Malloc(double,n);
 			for(int i=0;i<n;i++)
-			{
-				count = fscanf(fp,"%lf",&model->rho[i]);
-			  if (count <= 0)
-			  {
-			    REprintf("unknown text in model file: [%s]\n",cmd);
-			    
-			    setlocale(LC_ALL, old_locale);
-			    free(old_locale);
-			    free(model->rho);
-			    free(model->label);
-			    free(model->nSV);
-			    free(model);
-			    return NULL;
-			  }
-			}
+				fscanf_output = fscanf(fp,"%lf",&model->rho[i]);
 		}
 		else if(strcmp(cmd,"label")==0)
 		{
 			int n = model->nr_class;
 			model->label = Malloc(int,n);
 			for(int i=0;i<n;i++)
-			{
-				count = fscanf(fp,"%d",&model->label[i]);
-			  if (count <= 0)
-			  {
-			    REprintf("unknown text in model file: [%s]\n",cmd);
-			    
-			    setlocale(LC_ALL, old_locale);
-			    free(old_locale);
-			    free(model->rho);
-			    free(model->label);
-			    free(model->nSV);
-			    free(model);
-			    return NULL;
-			  }
-			}
+				fscanf_output = fscanf(fp,"%d",&model->label[i]);
 		}
 		else if(strcmp(cmd,"probA")==0)
 		{
 			int n = model->nr_class * (model->nr_class-1)/2;
 			model->probA = Malloc(double,n);
 			for(int i=0;i<n;i++)
-			{
-				count = fscanf(fp,"%lf",&model->probA[i]);
-			  if (count <= 0)
-			  {
-			    REprintf("unknown text in model file: [%s]\n",cmd);
-			    
-			    setlocale(LC_ALL, old_locale);
-			    free(old_locale);
-			    free(model->rho);
-			    free(model->label);
-			    free(model->nSV);
-			    free(model);
-			    return NULL;
-			  }
-			}
+				fscanf_output = fscanf(fp,"%lf",&model->probA[i]);
 		}
 		else if(strcmp(cmd,"probB")==0)
 		{
 			int n = model->nr_class * (model->nr_class-1)/2;
 			model->probB = Malloc(double,n);
 			for(int i=0;i<n;i++)
-			{
-				count = fscanf(fp,"%lf",&model->probB[i]);
-			  if (count <= 0)
-			  {
-			    REprintf("unknown text in model file: [%s]\n",cmd);
-			    
-			    setlocale(LC_ALL, old_locale);
-			    free(old_locale);
-			    free(model->rho);
-			    free(model->label);
-			    free(model->nSV);
-			    free(model);
-			    return NULL;
-			  }
-			}
+				fscanf_output = fscanf(fp,"%lf",&model->probB[i]);
 		}
 		else if(strcmp(cmd,"nr_sv")==0)
 		{
 			int n = model->nr_class;
 			model->nSV = Malloc(int,n);
 			for(int i=0;i<n;i++)
-			{
-				count = fscanf(fp,"%d",&model->nSV[i]);
-			  if (count <= 0)
-			  {
-			    REprintf("unknown text in model file: [%s]\n",cmd);
-			    
-			    setlocale(LC_ALL, old_locale);
-			    free(old_locale);
-			    free(model->rho);
-			    free(model->label);
-			    free(model->nSV);
-			    free(model);
-			    return NULL;
-			  }
-			}
+				fscanf_output = fscanf(fp,"%d",&model->nSV[i]);
 		}
 		else if(strcmp(cmd,"SV")==0)
 		{
